Active Mobility Centre
Author: Active Mobility
Description: tag line
Keywords: , default key words

- Change text size:

My shopping basket
0 items | £0.00

Login | Register

Active Mobility Centre
For help and information call 01642 805050

## VAT Exempt Pricing

## Ordering and Pricing Options

We are able to sell many of our products without VAT to those eligible for VAT relief. Click here for more information
We accept online and offline orders from individuals and official bodies with a variety of payment methods. Click here for more information.
Hide
Tick here if you DO NOT qualify for VAT exemption

# Welcome to Active Mobility

Suppliers of Disabled and Mobility Equipment for a More Active Life

At the Active Mobility Centre we offer a wide range of products to help make your life easier but most important of all we offer the expert help and advice that you deserve and an excellent after sales service which as a wheelchair user myself I find to be invaluable.

A selection of our products are available to order through our on line shop, but if you do not find what you are looking for or if you require any further information then please contact us on 01642 805050 or enq@activemobility.co.uk where one of our highly knowledgeable staff will be only too pleased to help.

If you do not wish to order on line we accept orders by post or fax and if you do not wish to make payment via our secure credit card payment facility we accept payment by cheque/postal order, BACS and PayPal.

Please note that certain items in our on-line shop are VAT exempt for people who are chronically sick or disabled and they are being used for their own personal use.

Don't forget to subscribe to our mailing list - it is packed with useful information, hints and tips, expert advice and news of the latest technological developments as well as details of our newest products to improve your ability to handle everyday situations.

We carry a wide range of products, including Bariatrics, Bathroom and Toilet items, Beds and accessories, Incontinence products, Footwear & footcare, Hearing Aids, Hoists and Patient Transfer, Wheelchairs and hosts of other items - just too many to mention all of them here.

We pride ourselves on the high quality of our service and the great value that we offer in our prices. If there is anything that you cannot find on our website or if you'd like to suggest any changes, we'd love to hear from you - please email us, or call us on 01642 805050.

Find out more

## Featured Products

Quickie Xenon2 Swing Away Wheelchair
£2,055.00
Abbi Black/Red Frame Reading Glasses
£15.95
Quickie Salsa R2 Powerchair
£3,995.00
Fully Portable Hoist
£2,356.43
Alber E-Motion M15 Powered Wheelchair Wheels
£3,995.00
Schwalbe Rightrun Wheelchair Tyre
£14.99
Cannington Fireside Chair
£375.00
Quickie Helium Ultra-lightweight Wheelchair
£1,995.00
Copyright © 1999 - 2015 Active Mobility Centre Ltd. All Rights Reserved.
VAT Reg: 633348052 Company Reg: 3479911 Web development by Graith